@@ -4,6 +4,14 @@ from typing import Optional, List, Dict, Union, Set
 import pendulum
 import pyotp
 import logging
+import warnings
+
+DEPRECATION_WARNING = """
+This module would be replaced by the more common Noren
+module from version 0.20.0.
+See https://github.com/uberdeveloper/omspy-brokers for the legacy module (not actively maintained)
+"""
+warnings.warn(DEPRECATION_WARNING, DeprecationWarning, stacklevel=2)
 
 
 class Finvasia(Broker):
@@ -26,7 +34,7 @@ class Finvasia(Broker):
         self._vendor_code = vendor_code
         self._app_key = app_key
         self._imei = imei
-        self.finvasia = ShoonyaApiPy()
+        self.finvasia = None
         super(Finvasia, self).__init__()
 
     @property
@@ -47,6 +55,7 @@ class Finvasia(Broker):
         """
         Authenticate the user
         """
+        self.finvasia = ShoonyaApiPy()
         return self.login()
 
     def _convert_symbol(self, symbol: str, exchange: str = "NSE") -> str:
@@ -65,8 +74,8 @@ class Finvasia(Broker):
     @post
     def orders(self) -> List[Dict]:
         orderbook = self.finvasia.get_order_book()
-        if len(orderbook) == 0:
-            return orderbook
+        if not orderbook:
+            return []
 
         order_list = []
         float_cols = ["avgprc", "prc", "rprc", "trgprc"]
@@ -77,13 +86,16 @@ class Finvasia(Broker):
                     order[int_col] = int(order.get(int_col, 0))
                 for float_col in float_cols:
                     order[float_col] = float(order.get(float_col, 0))
-                ts = order["exch_tm"]
-                # Timestamp converted to str to facilitate loading into pandas dataframe
-                order["exchange_timestamp"] = str(
-                    pendulum.from_format(
-                        ts, fmt="DD-MM-YYYY HH:mm:ss", tz="Asia/Kolkata"
+                ts = order.get("exch_tm")
+                if ts:
+                    # Timestamp converted to str to facilitate loading into pandas dataframe
+                    order["exchange_timestamp"] = str(
+                        pendulum.from_format(
+                            ts, fmt="DD-MM-YYYY HH:mm:ss", tz="Asia/Kolkata"
+                        )
                     )
-                )
+                else:
+                    order["exchange_timestamp"] = None
                 ts2 = order["norentm"]
                 order["broker_timestamp"] = str(
                     pendulum.from_format(
