@@ -1,6 +1,7 @@
 """
 This module contains the list of basic models
 """
+
 from pydantic import BaseModel, validator, PrivateAttr
 from typing import Optional, List, Union
 from copy import deepcopy
@@ -312,7 +313,7 @@ class CandleStick(BaseModel):
                 end_time=pendulum.today(tz=self.timezone).add(hours=15, minutes=30),
             )
             self.timer = timer
-        period = pendulum.period(self.timer.start_time, self.timer.end_time)
+        period = pendulum.interval(self.timer.start_time, self.timer.end_time)
         for p in period.range("seconds", self.interval):
             self.periods.append(p)
         # The first period is popped since it is the start
